@@ -26,3 +26,11 @@ generics::augment
 #' @importFrom generics required_pkgs
 #' @export
 generics::required_pkgs
+
+#' @importFrom hardhat extract_spec_parsnip
+#' @export
+hardhat::extract_spec_parsnip
+
+#' @importFrom hardhat extract_fit_engine
+#' @export
+hardhat::extract_fit_engine
