@@ -1,4 +1,4 @@
-#' General Interface for Parametric Survival Models
+#' Parametric survival regression
 #'
 #' `survival_reg()` is a way to generate a _specification_ of a model
 #'  before fitting and allows the model to be created using
@@ -14,8 +14,11 @@
 #'  functions. If parameters need to be modified, `update()` can be used
 #'  in lieu of recreating the object from scratch.
 #'
-#' @param mode A single character string for the type of model.
+#' @param mode A single character string for the prediction outcome mode.
 #'  The only possible value for this model is "censored regression".
+#' @param engine A single character string specifying what computational engine
+#'  to use for fitting. Possible engines are listed below. The default for this
+#'  model is `"survival"`.
 #' @param dist A character string for the outcome distribution. "weibull" is
 #'  the default.
 #' @details
@@ -24,17 +27,15 @@
 #' mode will always be "censored regression".
 #'
 #' Since survival models typically involve censoring (and require the use of
-#' [survival::Surv()] objects), the [fit()] function will require that the
+#' [survival::Surv()] objects), the [fit.model_spec()] function will require that the
 #' survival model be specified via the formula interface.
 #'
-#' @seealso [fit()], [survival::Surv()], [set_engine()], [update()]
+#' @seealso [fit.model_spec()], [survival::Surv()], [set_engine()], [update()]
 #' @examples
 #' survival_reg()
-#' # Parameters can be represented by a placeholder:
-#' survival_reg(dist = varying())
 #' @keywords internal
 #' @export
-survival_reg <- function(mode = "censored regression", dist = NULL) {
+survival_reg <- function(mode = "censored regression", engine = "survival", dist = NULL) {
 
   args <- list(
     dist = enquo(dist)
@@ -46,7 +47,7 @@ survival_reg <- function(mode = "censored regression", dist = NULL) {
     eng_args = NULL,
     mode = mode,
     method = NULL,
-    engine = NULL
+    engine = engine
   )
 }
 
